function E = Cdist_error(Cdist,x,Pa,par_filt,gp,aPd,Cd0,L,N,par_nephron)
% Function INPUTS:
%   Cdist: sodium concentration in distal tubule 
%   x: variables
%       Qe: output blood flow
%       Qi: input blood flow
%       P1: hydrostatic pressure in the capillary
%       P2: hydrostatic pressure in Bowman's capsule
%   Pa: input arterial pressure
%   par_filt: list of parameter values for glomerular filtration model
%   gp: ratio [input flow into the descending limb Qd0 / glomerular filtration
%              rate Qf]
%   aPd: ratio [distal tubule (and descending limb) hydrostatic pressure Pd / 
%               input arterial pressure Pa]
%   Cd0: input concentration in to the descending limb
%   L: length of nephron
%   N: number of numerical grid points
%   par_nephron: list of parameter values
%   par_nephron: list of parameter values for nephron model

opt_options = optimset('Algorithm','trust-region-dogleg','LargeScale','off','Display','off');
% Computing pressures and flows
x = fsolve(@KS_glomer_error,x,opt_options,Pa,par_filt,Cdist);
Qe = x(1);
Qi = x(2);
Qf = Qi - Qe;

% Computing concentrations and flows in nephron model
[Qd,Qc,Qs,Cd,Cc,Ca,Cs] = nephron_model(gp*Qf,Cd0,aPd*Pa,L,N,par_nephron);

E = Cdist - Ca(1);
