function E = KS_glomer_error(x,Pa,par,Cdist)
% Function INPUTS:
%   x: variables
%       Qe: output blood flow
%       Qi: input blood flow
%       P1: hydrostatic pressure in the capillary
%       P2: hydrostatic pressure in Bowman's capsule
%   Pa: input arterial pressure (mmHg)
%   par: list of parameter values
%   Cdist: sodium concentration in distal tubule 

% Variables
Qe = x(1);
Qi = x(2);
P1 = x(3);
P2 = x(4);

% Glomerular parameters
Pi_i = 28;      % input oncontic pressure (mmHg)
KfL = par(1);   % filtration rate (ml/min/mmHg)
Rd  = par(2);   % resistance proximal tubule (mmHg*min/ml)
% Juxtaglomerular apparatus parameters
Ramin  = par(3);
Ra0   = par(4);
Qi0  = par(5);
n_i  = par(6);
m    = par(7);
b    = par(8);
Remax  = par(9);
Ctgf = par(10);
Ntgf = 1;
Pe0  = par(11);
Pe1  = par(12);
Pe2  = par(13);
nPe  = par(14);
aPd  = 0.02;

Pe = Pe0 + Pe1*Pa^nPe / (Pa^nPe + Pe2^nPe );
Pd = aPd*Pa;

% Juxtaglomerular apparatus model
Qf = Qi - Qe;

% Afferent and efferent resistances
Ra = Ra0 * ( 1 / ((Qi0/Qi)^n_i + 1) ) * Cdist^Ntgf / (Cdist^Ntgf + Ctgf^Ntgf) + Ramin;
Re = min(Remax,-m*P1+b);

% Model Algebraic equations
alpha = Pi_i / (P1 - P2);
A = log((Qe/Qi-alpha)/(1-alpha));
if isreal(A)
  E(1) = (Qe/Qi) + alpha*A - 1 + KfL*Pi_i/(alpha*Qi);
else
  E(1) = 999;
end
E(2) = Pa - P1 - Qi*Ra;
E(3) = P1 - Pe - Qe*Re;
E(4) = P2 - Pd - Rd*Qf;


