% clear
%% DATA
% Note: the datasets used in this study were obtained by digitizing the figures from the
% articles referenced below.

% From Roman AJP Renal Physiol 251:F57-F65, 1986
Data_hs1 = [50.5  60.3     72    81  86.3  94.3   103   108    116    125    137   147
             1.4   1.9   2.92  3.31  3.68  3.99  4.32  4.44   4.43   4.52   4.67   4.78];        
Data_ls1 = [49.3  61.3     73  79.3  87.3  93.8   101   108    117    132    138   144
            2.12  3.26   4.02  4.46  4.51  4.53  4.55   4.6   4.56   4.71   4.91   5]; 
Data_sr1 = [52.8  65.8     75  83.3  88.8  95.5   102   108    118  
            3.15   4.2   4.74  5.13  5.28  5.42   5.5  5.51  5.75];  
Data_hs2 = [115    144    169   200
          0.481  0.724  0.892 0.914]; 
Data_ls2 = [103    128    153    181
           0.697  0.93  0.935  0.919];
Data_sr2 = [101    127    151         
            1.06  1.08   1.11];
Data_hs3 = [119    157    199
           39.2   48.3   52.0];
Data_sr3 = [105   144     161
            44.4   52      53];
Data_hs4 = [119    156    199
           12.8   18.5   23.2];    
Data_sr4 = [105    144    161
           13.3   18.9  21.6]; 
Data_hs5 = [115    144   169   200
           1.04   3.52  9.46  11.4];
Data_ls5 = [102    129   153   181
           1.59      5  7.22  9.31];
Data_sr5 = [102    129   153
           2.52   8.45  16.1];
Data_hs6 = [117    144   169   201
            7.5     24    52   70];
Data_ls6 = [102    130   153   181
             12     33    46    60];
Data_sr6 = [100    127   153
             18     50   93.5];

% From Roman and Kaldunski AJP Regul Integr Comp Physiol 261:R595-R602,
% 1991.
Data_hs5b = [118    152    185
            1.78   8.01   14.2];    
Data_sr5b = [99.1   126   155
             6.16  11.5   16.8];    
Data_hs6b = [118    152    186
             9.5   44.6    88.8];   
Data_sr6b = [99.1   127    156
             33.1    62    97.5];   

% From Thompson and Pitts, AJP  168:490-499, 1652 (text file attached)
fid = fopen('Fig1Normal_Thompson_Pitts.txt');
Data_dog_normal_QuCu = fscanf(fid, '%f %f', [2 inf]);
fid = fopen('Fig3Normal_Thompson_Pitts.txt');
Data_dog_normal_Qu = fscanf(fid, '%f %f', [2 inf]);


%% Model Parameters 
% Filtration model (SR):
KfL  = 0.0886;
Rd   = 7.4959; 
Ramin  = 2.8758;
Ra0   = 37.7673;
Qi0  = 5.5796;
n_i  = 9.5614;
m    = 0.5269;
b    = 37.5995;
Remax  = 7.4185;
Ctgf = 25;
Pe0  = 10.4;
Pe1  = 15.1;
Pe2  = 136.5;
nPe  = 5.93;

% Nephron model (SR):
Hd   = 0.0077;   
Kd   = 0.00083889;  
Kc   = 1.8777e-005; 
Pmax = 29.172;
Kmp  = 50.933;

% SR model parameters:
par_filt_sr = [KfL Rd Ramin Ra0 Qi0 n_i m b Remax Ctgf Pe0 Pe1 Pe2 nPe ];
par_nephron_sr = [Hd Kd Kc Pmax Kmp ];
% LS model parameters
par_filt_ls    = par_filt_sr;
par_nephron_ls = par_nephron_sr;
par_filt_ls(3) = 4.8848;
par_filt_ls(5) = 4.2777;
par_filt_ls(7) = 0.5774;
par_filt_ls(9) = 13.124; 

% HS model parameters
par_filt_hs     = par_filt_ls;
par_nephron_hs  = par_nephron_ls;
par_filt_hs(3)  = 9.8356;
par_filt_hs(9)  = 9.1024;
par_filt_hs(7)  = 0.5431;
par_filt_hs(11) = 8.32;

%% Other parameters
Cd0 = 150;
gp = 0.33;
aPd  = 0.0200;
L = 2;
N = 100;
dy = L/N;
y = (0.5:1:N)'.*dy;

%% Making Plots
% Initial guess for flow variables
Qe = 4.0;   % (ml/min/g)
Qi = 5.0;
P1 = 50; 
P2 = 4; 
x0 = [Qe Qi P1 P2];
Pa = 45:5:205;

x_sr = x0;
Cdist = 60; % initial guess for Cdist (Concentration in distal tubule)
for i = length(Pa):-1:1
  i  
  opt_options = optimset('TolX',1e-1,'Display','off');  
  Cdist = fzero(@Cdist_error,Cdist,opt_options,x_sr,Pa(i),par_filt_sr,gp,aPd,Cd0,L,N,par_nephron_sr)
%   Cdist = 32*(Pa(i) - 100)/100 + 25; % HS approximation

  opt_options = optimset('Algorithm','trust-region-dogleg','LargeScale','off','TolFun',1e-4);
  % Computing pressures and flows
  x_sr = fsolve(@KS_glomer_error,x_sr,opt_options,Pa(i),par_filt_sr,Cdist);
  Qe_sr(i) = x_sr(1);
  Qi_sr(i) = x_sr(2);
  Qf_sr(i) = Qi_sr(i)-Qe_sr(i);
  P1_sr(i) = x_sr(3);
  P2_sr(i) = x_sr(4);

  % Computing pressures and flows
  [Qd,Qc,Qs,Cd,Cc,Ca,Cs] = nephron_model(gp*Qf_sr(i),Cd0,aPd*Pa(i),L,N,par_nephron_sr);
  Qu_sr(i) = Qc(N);
  Cu_sr(i) = Cc(N);
  Cdist = Ca(1);
  Cdist_sr(i) = Cdist;
  
end

% LS
x_ls = x0;
Cdist = 60; % initial guess for Cdist
for i = length(Pa):-1:1
  i
  opt_options = optimset('TolX',1e-1,'Display','off');  
  Cdist = fzero(@Cdist_error,Cdist,opt_options,x_ls,Pa(i),par_filt_ls,gp,aPd,Cd0,L,N,par_nephron_ls)
%   Cdist = 22*(Pa(i) - 100)/100 + 25; % LS approximation

  opt_options = optimset('Algorithm','trust-region-dogleg','LargeScale','off','TolFun',1e-4);
  % Computing pressures and flows
  x_ls = fsolve(@KS_glomer_error,x_ls,opt_options,Pa(i),par_filt_ls,Cdist);
  Qe_ls(i) = x_ls(1);
  Qi_ls(i) = x_ls(2);
  Qf_ls(i) = Qi_ls(i)-Qe_ls(i);
  P1_ls(i) = x_ls(3);
  P2_ls(i) = x_ls(4);

  % Computing pressures and flows
  [Qd,Qc,Qs,Cd,Cc,Ca,Cs] = nephron_model(gp*Qf_ls(i),Cd0,aPd*Pa(i),L,N,par_nephron_ls);
  Qu_ls(i) = Qc(N);
  Cu_ls(i) = Cc(N);
  Cdist = Ca(1);
  Cdist_ls(i) = Cdist;
  
end

% HS
x_hs = x0;
Cdist = 50; % initial guess for Cdist
for i = length(Pa):-1:1
  i  
  opt_options = optimset('TolX',1e-1,'Display','off');  
  Cdist = fzero(@Cdist_error,Cdist,opt_options,x_hs,Pa(i),par_filt_hs,gp,aPd,Cd0,L,N,par_nephron_hs)
%   Cdist = 32*(Pa(i) - 100)/100 + 25; % HS approximation

  opt_options = optimset('Algorithm','trust-region-dogleg','LargeScale','off','TolFun',1e-4);
  % Computing pressures and flows
  x_hs = fsolve(@KS_glomer_error,x_hs,opt_options,Pa(i),par_filt_hs,Cdist);
  Qe_hs(i) = x_hs(1);
  Qi_hs(i) = x_hs(2);
  Qf_hs(i) = Qi_hs(i)-Qe_hs(i);
  P1_hs(i) = x_hs(3);
  P2_hs(i) = x_hs(4);

  % Computing pressures and flows
  [Qd,Qc,Qs,Cd,Cc,Ca,Cs] = nephron_model(gp*Qf_hs(i),Cd0,aPd*Pa(i),L,N,par_nephron_hs);
  Qu_hs(i) = Qc(N);
  Cu_hs(i) = Cc(N);
  Cdist = Ca(1);
  Cdist_hs(i) = Cdist;
  
end

% Figure 2A 
figure(1); clf; ax1 = axes('position',[0.15 0.15 0.73 0.78]); hold on;
plot(Pa,Qi_hs,'k:','linewidth',1.5); 
plot(Pa,Qi_ls,'k--','linewidth',1.5); 
plot(Pa,Qi_sr,'k-','linewidth',1.5); 
plot(Data_hs1(1,:),Data_hs1(2,:),'ko','linewidth',1.5,'MarkerFaceColor',[1 1 1]);
plot(Data_ls1(1,:),Data_ls1(2,:),'k^','linewidth',1.5,'MarkerFaceColor',[1 1 1]);
plot(Data_sr1(1,:),Data_sr1(2,:),'ks','linewidth',1.5,'MarkerFaceColor',0.5*[1 1 1]);
% plot(Qi_m(1,:),Qi_m(2,:),'r+-');
xlabel('$P_a$ (mmHg)','interpreter','latex','fontsize',16);
set(ax1,'Fontsize',14);
ylabel('Input flow $Q_i$ (ml$\cdot$min$^{-1}\cdot$g$^{-1}$)','interpreter','latex','fontsize',16);
axis([40 220 0 7]); box on;
text(160,4.00,'SS (high-salt)','interpreter','latex','fontsize',16);
text(160,4.95,'SS (low-salt)','interpreter','latex','fontsize',16);
text(160,6.00,'SR','interpreter','latex','fontsize',16);

% Figure 2B 
figure(2); clf; ax1 = axes('position',[0.15 0.15 0.73 0.78]); hold on;
plot(Pa,Qf_hs,'k:','linewidth',1.5); 
plot(Pa,Qf_ls,'k--','linewidth',1.5); 
plot(Pa,Qf_sr,'k-','linewidth',1.5); 
plot(Data_hs2(1,:),Data_hs2(2,:),'ko','linewidth',1.5,'MarkerFaceColor',[1 1 1]);
plot(Data_ls2(1,:),Data_ls2(2,:),'k^','linewidth',1.5,'MarkerFaceColor',[1 1 1]);
plot(Data_sr2(1,:),Data_sr2(2,:),'ks','linewidth',1.5,'MarkerFaceColor',0.5*[1 1 1]);
% plot(Qf_m(1,:),Qf_m(2,:),'r+-');
xlabel('$P_a$ (mmHg)','interpreter','latex','fontsize',16);
set(ax1,'Fontsize',14);
ylabel('Filtrate flow $Q_f$ (ml$\cdot$min$^{-1}\cdot$g$^{-1}$)','interpreter','latex','fontsize',16);
axis([40 220 0 1.25]); box on;

% Figure 2C 
figure(3); clf; ax1 = axes('position',[0.15 0.15 0.73 0.78]); hold on;
plot(Pa,P1_hs,'k:','linewidth',1.5); 
plot(Pa,P1_ls,'k--','linewidth',1.5); 
plot(Pa,P1_sr,'k-','linewidth',1.5); 
plot(Data_hs3(1,:),Data_hs3(2,:),'ko','linewidth',1.5,'MarkerFaceColor',[1 1 1]);
plot(Data_sr3(1,:),Data_sr3(2,:),'ks','linewidth',1.5,'MarkerFaceColor',0.5*[1 1 1]);
xlabel('$P_a$ (mmHg)','interpreter','latex','fontsize',16);
set(ax1,'Fontsize',14);
ylabel('Glomerular pressure $P_1$ (mmHg)','interpreter','latex','fontsize',16);
axis([40 220 0 60]); box on;

Pe0_sr = par_filt_sr(11);
Pe1_sr = par_filt_sr(12);
Pe2_sr = par_filt_sr(13);
nPe_sr = par_filt_sr(14);
aPd_sr = 0.02;
Pe_sr = Pe0_sr + Pe1_sr.*Pa.^nPe_sr ./ (Pa.^nPe_sr + Pe2_sr^nPe_sr );
Pd_sr = aPd_sr.*Pa;

Pe0_hs = par_filt_hs(11);
Pe1_hs = par_filt_hs(12);
Pe2_hs = par_filt_hs(13);
nPe_hs = par_filt_hs(14);
aPd_hs = 0.02;
Pe_hs = Pe0_hs + Pe1_hs.*Pa.^nPe_hs ./ (Pa.^nPe_hs + Pe2_hs^nPe_hs );
Pd_hs = aPd_hs.*Pa;

Pe0_ls = par_filt_ls(11);
Pe1_ls = par_filt_ls(12);
Pe2_ls = par_filt_ls(13);
nPe_ls = par_filt_ls(14);
aPd_ls = 0.02;
Pe_ls = Pe0_ls + Pe1_ls.*Pa.^nPe_ls ./ (Pa.^nPe_ls + Pe2_ls^nPe_ls );
Pd_ls = aPd_ls.*Pa;

% Figure 2D 
figure(4); clf; ax1 = axes('position',[0.15 0.15 0.73 0.78]); hold on;
plot(Pa,Pe_hs,'k:','linewidth',1.5); 
plot(Pa,Pe_ls,'k--','linewidth',1.5); 
plot(Pa,Pe_sr,'k-','linewidth',1.5); 
plot(Pa,Pd_ls,'k-','linewidth',1.5);
plot(Data_hs4(1,:),Data_hs4(2,:),'ko','linewidth',1.5,'MarkerFaceColor',[1 1 1]);
plot(Data_sr4(1,:),Data_sr4(2,:),'ks','linewidth',1.5,'MarkerFaceColor',0.5*[1 1 1]);
xlabel('$P_a$ (mmHg)','interpreter','latex','fontsize',16);
set(ax1,'Fontsize',14);
ylabel('Pressure (mmHg)','interpreter','latex','fontsize',16);
text(120,19,'$P_e$','interpreter','latex','fontsize',16);
text(120,4,'$P_d$','interpreter','latex','fontsize',16);
axis([40 220 0 30]); box on;

Ntgf = 1;
ra0  = par_filt_sr(3);
ra   = par_filt_sr(4);
Qi0  = par_filt_sr(5);
n_i  = par_filt_sr(6);
m    = par_filt_sr(7);
b    = par_filt_sr(8);
re0  = par_filt_sr(9);
Ctgf = par_filt_sr(10);
Ra_sr = ra * ( Qi_sr.^n_i ./ (Qi0^n_i + Qi_sr.^n_i) ) .* Cdist_sr.^Ntgf ./ (Cdist_sr.^Ntgf + Ctgf^Ntgf) + ra0;
Re_sr = min(re0,-m*P1_sr+b);

ra0  = par_filt_ls(3);
ra   = par_filt_ls(4);
Qi0  = par_filt_ls(5);
n_i  = par_filt_ls(6);
m    = par_filt_ls(7);
b    = par_filt_ls(8);
re0  = par_filt_ls(9);
Ctgf = par_filt_ls(10);
Ra_ls = ra * ( Qi_ls.^n_i ./ (Qi0^n_i + Qi_ls.^n_i) ) .* Cdist_ls.^Ntgf ./ (Cdist_ls.^Ntgf + Ctgf^Ntgf) + ra0;
Re_ls = min(re0,-m*P1_ls+b);

ra0  = par_filt_hs(3);
ra   = par_filt_hs(4);
Qi0  = par_filt_hs(5);
n_i  = par_filt_hs(6);
m    = par_filt_hs(7);
b    = par_filt_hs(8);
re0  = par_filt_hs(9);
Ctgf = par_filt_hs(10);
Ra_hs = ra * ( Qi_hs.^n_i ./ (Qi0^n_i + Qi_hs.^n_i) ) .* Cdist_hs.^Ntgf ./ (Cdist_hs.^Ntgf + Ctgf^Ntgf) + ra0;
Re_hs = min(re0,-m*P1_hs+b);

% Figure 1B 
figure(5); clf; ax1 = axes('position',[0.15 0.15 0.73 0.78]); hold on;
plot(Pa,Ra_hs,'k:','linewidth',1.5); 
plot(Pa,Ra_ls,'k--','linewidth',1.5); 
plot(Pa,Ra_sr,'k-','linewidth',1.5); 
ylabel('Resistance, $R_a$ (min$\cdot$g$\cdot$mmHg$\cdot$ml$^{-1}$)','interpreter','latex','fontsize',16);
xlabel('$P_a$ (mmHg)','interpreter','latex','fontsize',16);
set(gca,'Fontsize',14);
axis([40 220 0 25]); box on;
l = legend('SS (high-salt)','SS (low-salt)','SR',4);
set(l,'interpreter','latex','fontsize',14);

% Figure 1C 
figure(6); clf; ax1 = axes('position',[0.15 0.15 0.73 0.78]); hold on;
plot(Pa,Re_hs,'k:','linewidth',1.5);
plot(Pa,Re_ls,'k--','linewidth',1.5);
plot(Pa,Re_sr,'k-','linewidth',1.5);
ylabel('Resistance, $R_e$ (min$\cdot$g$\cdot$mmHg$\cdot$ml$^{-1}$)','interpreter','latex','fontsize',16);
xlabel('$P_a$ (mmHg)','interpreter','latex','fontsize',16);
set(gca,'Fontsize',14);
axis([40 220 0 15]); box on;
l = legend('SS (high-salt)','SS (low-salt)','SR',3);
set(l,'interpreter','latex','fontsize',14);

% Figure 3A 
figure(7); clf; axes('position',[0.15 0.15 0.73 0.78]); hold on;
plot(Pa,1000*Qu_hs,'k:','linewidth',1.5);
plot(Pa,1000*Qu_ls,'k--','linewidth',1.5);
plot(Pa,1000*Qu_sr,'k-','linewidth',1.5);
plot(Data_hs6(1,:),Data_hs6(2,:),'ko','linewidth',1.5,'MarkerFaceColor',[1 1 1]);
plot(Data_ls6(1,:),Data_ls6(2,:),'k^','linewidth',1.5,'MarkerFaceColor',[1 1 1]);
plot(Data_sr6(1,:),Data_sr6(2,:),'ks','linewidth',1.5,'MarkerFaceColor',0.5*[1 1 1]);
plot(Data_sr6b(1,:),Data_sr6b(2,:),'kd','linewidth',1.5,'MarkerFaceColor',0.5*[1 1 1]);
% plot(Qu_m(1,:),Qu_m(2,:),'r+-');
% plot(Qu_m(1,:),Qu_m(2,:)/2,'r+--');
xlabel('$P_a$ (mmHg)','interpreter','latex','fontsize',16);
set(gca,'Fontsize',14);
xlabel('$P_a$ (mmHg)','interpreter','latex','fontsize',16);
ylabel('Urine output ($\mu$l$\cdot$min$^{-1}\cdot$g$^{-1}$)','interpreter','latex','fontsize',16);
axis([40 220 0 100]); box on;

% Figure 3B 
figure(8); clf; axes('position',[0.15 0.15 0.73 0.78]); hold on;
plot(Pa,Qu_hs.*Cu_hs,'k:','linewidth',1.5);
plot(Pa,Qu_ls.*Cu_ls,'k--','linewidth',1.5);
plot(Pa,Qu_sr.*Cu_sr,'k-','linewidth',1.5);
plot(Data_hs5(1,:),Data_hs5(2,:),'ko','linewidth',1.5,'MarkerFaceColor',[1 1 1]);
plot(Data_ls5(1,:),Data_ls5(2,:),'k^','linewidth',1.5,'MarkerFaceColor',[1 1 1]);
plot(Data_sr5(1,:),Data_sr5(2,:),'ks','linewidth',1.5,'MarkerFaceColor',0.5*[1 1 1]);
plot(Data_sr5b(1,:),Data_sr5b(2,:),'kd','linewidth',1.5,'MarkerFaceColor',0.5*[1 1 1]);
xlabel('$P_a$ (mmHg)','interpreter','latex','fontsize',16);
set(gca,'Fontsize',14);
xlabel('$P_a$ (mmHg)','interpreter','latex','fontsize',16);
ylabel('Na$^+$ excretion ($\mu$Eq$\cdot$min$^{-1}\cdot$g$^{-1}$)','interpreter','latex','fontsize',16);
axis([40 220 0 20]); box on;

% Figure 5A 
figure(9); clf; axes('position',[0.15 0.15 0.73 0.78]); hold on;
plot( Qf_sr./Qf_sr(17), Qu_sr./Qu_sr(17), 'k-', 'linewidth', 1.5);
plot( [0 3], [1 1], 'k--' );
plot( [1 1], [0 3], 'k--' );
plot(Data_dog_normal_Qu(1,:)/100,Data_dog_normal_Qu(2,:)/100,'kd','linewidth',1.5,'MarkerFaceColor',0.5*[1 1 1]);
set(gca,'Fontsize',14);
xlabel('$Q_f$ (rel. change)','interpreter','latex','fontsize',16);
ylabel('$Q_u$ (rel. change)','interpreter','latex','fontsize',16);
axis([0 2 0 2]); box on;

% Figure 5B 
figure(10); clf; axes('position',[0.15 0.15 0.73 0.78]); hold on;
plot( Qf_sr./Qf_sr(17), Qu_sr.*Cu_sr./Qu_sr(17)./Cu_sr(17), 'k-', 'linewidth', 1.5);
plot( [0 3], [1 1], 'k--' );
plot( [1 1], [0 3], 'k--' );
plot(Data_dog_normal_QuCu(1,:)/100,Data_dog_normal_QuCu(2,:)/100,'kd','linewidth',1.5,'MarkerFaceColor',0.5*[1 1 1]);
set(gca,'Fontsize',14);
xlabel('$Q_f$ (rel. change)','interpreter','latex','fontsize',16);
ylabel('$Q_u \cdot C_u$ (rel. change)','interpreter','latex','fontsize',16);
axis([0 2 0 2]); box on;

%% Illustration of P-N and P-D relationships

P = 0:2:160;
Qf = P.^4 ./ (P.^4 + 50^4);
Qu = max(0, 1.6*(P-100)/1000 );
Qf(52:end) = Qu(52:end)+0.942;

% Figure 6A 
figure(11); clf; ax1 = axes('position',[0.15 0.15 0.73 0.78]); hold on;
plot(P,Qf,'k-','linewidth',1.5); 
plot(P,Qu,'k-','linewidth',1.5); 
xlabel('$P_a$ (mmHg)','interpreter','latex','fontsize',16);
set(ax1,'Fontsize',14);
ylabel('Flow $Q_f$, $Q_u$ (ml$\cdot$min$^{-1}\cdot$g$^{-1}$)','interpreter','latex','fontsize',16);
axis([40 180 0 1.2]); box on;
text(80,1.0,'$Q_f$','interpreter','latex','fontsize',16);
text(80,0.15,'$Q_u = Q_f - $ constant','interpreter','latex','fontsize',16);

% Figure 6B 
figure(12); clf; ax1 = axes('position',[0.15 0.15 0.73 0.78]); hold on;
plot(P,Qu*150,'k-','linewidth',1.5); 
xlabel('$P_a$ (mmHg)','interpreter','latex','fontsize',16);
set(ax1,'Fontsize',14);
ylabel('Na$^+$ Excretion ($\mu$Eq$\cdot$min$^{-1}\cdot$g$^{-1}$)','interpreter','latex','fontsize',16);
text(100,12,'$Q_u\cdot$ 150 mM','interpreter','latex','fontsize',16);
axis([40 180 0 18]); box on;


%% Figure 4

Pa = 125; 
x_sr = x0;
Cdist = 50; % initial guess for Cdist
opt_options = optimset('TolX',1e-1,'Display','off');  
Cdist = fzero(@Cdist_error,Cdist,opt_options,x_sr,Pa,par_filt_sr,gp,aPd,Cd0,L,N,par_nephron_sr);
opt_options = optimset('Algorithm','trust-region-dogleg','LargeScale','off','TolFun',1e-4);
% Computing pressures and flows
x_sr = fsolve(@KS_glomer_error,x_sr,opt_options,Pa,par_filt_sr,Cdist);
Qe_sr = x_sr(1);
Qi_sr = x_sr(2);
Qf_sr = Qi_sr-Qe_sr;
% Computing pressures and flows
[Qd,Qc,Qs,Cd,Cc,Ca,Cs] = nephron_model(gp*Qf_sr,Cd0,aPd*Pa,L,N,par_nephron_sr);
Qa = -Qd(N);

% Figure 4A
figure(13); clf; ax1 = axes('position',[0.15 0.15 0.73 0.78]);
plot(y,Cd,'k-',y,Ca,'k-',y,Cc,'k-',y,Cs,'k--','linewidth',1.5); axis([0 L 0 300]);
set(gca,'Fontsize',16);
text(1.0,201,'$C_s$','interpreter','latex','fontsize',16);
text(1.0,159,'$C_d$','interpreter','latex','fontsize',16);
text(1.0,99,'$C_a$','interpreter','latex','fontsize',16);
text(1.0,42,'$C_c$','interpreter','latex','fontsize',16);
xlabel('$x$ (mm)','interpreter','latex','fontsize',16);
ylabel('[Na$^+$] (mM)','interpreter','latex','fontsize',16);

% Figure 4B
figure(14); clf; ax1 = axes('position',[0.15 0.15 0.73 0.78]);
plot(y,Qd,'k-',y,-Qa*ones(N,1),'k-',y,Qc,'k-','linewidth',1.5); axis([0 L 0 0.35]);
set(gca,'Fontsize',16);
text(1.0,0.28,'$q_d$','interpreter','latex','fontsize',18);
text(0.9,0.18,'$-q_a$','interpreter','latex','fontsize',18);
text(1.0,0.09,'$q_c$','interpreter','latex','fontsize',18);
xlabel('$x$ (mm)','interpreter','latex','fontsize',16);
ylabel('Flow (ml$\cdot$min$^{-1}\cdot$g$^{-1}$)','interpreter','latex','fontsize',16);

Pa = 95;
x_sr = x0;
Cdist = 50; % initial guess for Cdist
opt_options = optimset('TolX',1e-1,'Display','off');  
Cdist = fzero(@Cdist_error,Cdist,opt_options,x_sr,Pa,par_filt_sr,gp,aPd,Cd0,L,N,par_nephron_sr);
opt_options = optimset('Algorithm','trust-region-dogleg','LargeScale','off','TolFun',1e-4);
% Computing pressures and flows
x_sr = fsolve(@KS_glomer_error,x_sr,opt_options,Pa,par_filt_sr,Cdist);
Qe_sr(i) = x_sr(1);
Qi_sr(i) = x_sr(2);
Qf_sr(i) = Qi_sr(i)-Qe_sr(i);
% Computing pressures and flows
[Qd,Qc,Qs,Cd,Cc,Ca,Cs] = nephron_model(gp*Qf_sr(i),Cd0,aPd*Pa,L,N,par_nephron_sr);
Qa = -Qd(N);
 

% Figure 4C
figure(15); clf; ax1 = axes('position',[0.15 0.15 0.73 0.78]);
plot(y,Cd,'k-',y,Ca,'k-',y,Cc,'k-',y,Cs,'k--','linewidth',1.5); axis([0 L 0 500]);
set(gca,'Fontsize',16);
text(0.15,190,'$C_s$','interpreter','latex','fontsize',16);
text(0.15,126,'$C_d$','interpreter','latex','fontsize',16);
text(0.15,70,'$C_a$','interpreter','latex','fontsize',16);
text(0.83,70,'$C_c$','interpreter','latex','fontsize',16);
xlabel('$x$ (mm)','interpreter','latex','fontsize',16);
ylabel('[Na$^+$] (mM)','interpreter','latex','fontsize',16);

% Figure 4D
figure(16); clf; ax1 = axes('position',[0.15 0.15 0.73 0.78]);
plot(y,Qd,'k-',y,-Qa*ones(N,1),'k-',y,Qc,'k-','linewidth',1.5); axis([0 L 0 0.35]);
set(gca,'Fontsize',16);
text(0.614,0.251,'$q_d$','interpreter','latex','fontsize',18);
text(0.545,0.109,'$-q_a$','interpreter','latex','fontsize',18);
text(0.614,0.044,'$q_c$','interpreter','latex','fontsize',18);
xlabel('$x$ (mm)','interpreter','latex','fontsize',16);
ylabel('Flow (ml$\cdot$min$^{-1}\cdot$g$^{-1}$)','interpreter','latex','fontsize',16);

